Crate rusoto_connectparticipant

Crate rusoto_connectparticipant 

Amazon Connect is a cloud-based contact center solution that makes it easy to set up and manage a customer contact center and provide reliable customer engagement at any scale.

Amazon Connect enables customer contacts through voice or chat.

The APIs described here are used by chat participants, such as agents and customers.

If you’re using the service, you’re probably looking for ConnectParticipantClient and ConnectParticipant.

Structs

ConnectParticipantClient
A client for the Amazon Connect Participant API.
ConnectionCredentials

Connection credentials.

CreateParticipantConnectionRequest
CreateParticipantConnectionResponse
DisconnectParticipantRequest
DisconnectParticipantResponse
GetTranscriptRequest
GetTranscriptResponse
Item

An item - message or event - that has been sent.

SendEventRequest
SendEventResponse
SendMessageRequest
SendMessageResponse
StartPosition

A filtering option for where to start. For example, if you sent 100 messages, start with message 50.

Websocket

The websocket for the participant's connection.

Enums

CreateParticipantConnectionError
Errors returned by CreateParticipantConnection
DisconnectParticipantError
Errors returned by DisconnectParticipant
GetTranscriptError
Errors returned by GetTranscript
SendEventError
Errors returned by SendEvent
SendMessageError
Errors returned by SendMessage

Traits

ConnectParticipant
Trait representing the capabilities of the Amazon Connect Participant API. Amazon Connect Participant clients implement this trait.