Amazon Connect is a cloud-based contact center solution that makes it easy to set up and manage a customer contact center and provide reliable customer engagement at any scale.
Amazon Connect enables customer contacts through voice or chat.
The APIs described here are used by chat participants, such as agents and customers.
If you’re using the service, you’re probably looking for ConnectParticipantClient and ConnectParticipant.
Structs
- Connect
Participant Client - A client for the Amazon Connect Participant API.
- Connection
Credentials Connection credentials.
- Create
Participant Connection Request - Create
Participant Connection Response - Disconnect
Participant Request - Disconnect
Participant Response - GetTranscript
Request - GetTranscript
Response - Item
An item - message or event - that has been sent.
- Send
Event Request - Send
Event Response - Send
Message Request - Send
Message Response - Start
Position A filtering option for where to start. For example, if you sent 100 messages, start with message 50.
- Websocket
The websocket for the participant's connection.
Enums
- Create
Participant Connection Error - Errors returned by CreateParticipantConnection
- Disconnect
Participant Error - Errors returned by DisconnectParticipant
- GetTranscript
Error - Errors returned by GetTranscript
- Send
Event Error - Errors returned by SendEvent
- Send
Message Error - Errors returned by SendMessage
Traits
- Connect
Participant - Trait representing the capabilities of the Amazon Connect Participant API. Amazon Connect Participant clients implement this trait.